#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const debug = (process.argv.includes('--debug'));
const tracking = (/--tracking[=\s]+([^\s]*)/i).exec(process.argv.join(' '));
const analyticsDebug = process.argv.includes('--analytics-debug');
const d = require("debug");
const insights = require("../lib/utils/appinsights");
const configStore = require("../lib/utils/configstore");
if (debug) {
    d.enable('hint:*');
}
const trackingEnv = process.env.HINT_TRACKING;
let enableTracking;
if (tracking) {
    enableTracking = tracking[1] === 'on';
}
else if (trackingEnv) {
    enableTracking = trackingEnv === 'on';
}
if (typeof enableTracking !== 'undefined') {
    if (enableTracking) {
        const alreadyRun = configStore.get('run');
        const configured = insights.isConfigured();
        insights.enable();
        if (!configured) {
            if (!alreadyRun) {
                insights.trackEvent('FirstRun');
            }
            else {
                insights.trackEvent('SecondRun');
            }
        }
    }
    else {
        insights.disable();
    }
}
if (analyticsDebug && !debug) {
    d.enable('hint:utils:appinsights');
}
const cli = require("../lib/cli");
const appinsights_1 = require("../lib/utils/appinsights");
process.once('uncaughtException', async (err) => {
    console.error(err.message);
    console.error(err.stack);
    appinsights_1.trackException(err);
    await appinsights_1.sendPendingData();
    process.exit(1);
});
process.once('unhandledRejection', async (reason) => {
    const source = reason.error ? reason.error : reason;
    appinsights_1.trackException(source);
    await appinsights_1.sendPendingData();
    console.error(`Unhandled rejection promise:
    uri: ${source.uri}
    message: ${source.message}
    stack:
${source.stack}`);
    process.exit(1);
});
const run = async () => {
    process.exitCode = await cli.execute(process.argv);
    if (debug) {
        console.log(`Exit code: ${process.exitCode}`);
    }
    process.exit(process.exitCode);
};
run();
