"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const location_helpers_1 = require("./utils/location-helpers");
class HintContext {
    constructor(hintId, engine, severity, options, meta) {
        this.id = hintId;
        this.options = options;
        this.meta = meta;
        this.engine = engine;
        this.severity = severity;
        Object.freeze(this);
    }
    get pageDOM() {
        return this.engine.pageDOM;
    }
    get pageContent() {
        return this.engine.pageContent;
    }
    get pageHeaders() {
        return this.engine.pageHeaders;
    }
    get targetedBrowsers() {
        return this.engine.targetedBrowsers;
    }
    get hintOptions() {
        if (Array.isArray(this.options)) {
            return this.options[1];
        }
        return null;
    }
    evaluate(source) {
        return this.engine.evaluate(source);
    }
    fetchContent(target, headers) {
        return this.engine.fetchContent(target, headers);
    }
    querySelectorAll(selector) {
        return this.engine.querySelectorAll(selector);
    }
    findInElement(element, content) {
        return location_helpers_1.findInElement(element, content);
    }
    findProblemLocation(element, content) {
        return location_helpers_1.findProblemLocation(element, { column: 0, line: 0 }, content);
    }
    async report(resource, element, message, content, location, severity, codeSnippet) {
        let position = location;
        let sourceCode = null;
        if (element) {
            position = await location_helpers_1.findProblemLocation(element, { column: 0, line: 0 }, content);
            sourceCode = (await element.outerHTML()).replace(/[\t]/g, '    ');
        }
        this.engine.report(this.id, severity || this.severity, codeSnippet || sourceCode, position, message, resource);
    }
    on(event, listener) {
        this.engine.onHintEvent(this.id, event, listener);
    }
}
exports.HintContext = HintContext;
