"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class JSDOMAsyncHTMLDocument {
    constructor(document) {
        this._document = document;
    }
    querySelectorAll(selector) {
        try {
            const elements = Array.prototype.slice.call(this._document.querySelectorAll(selector))
                .map((element) => {
                return new JSDOMAsyncHTMLElement(element);
            });
            return Promise.resolve(elements);
        }
        catch (e) {
            return Promise.resolve([]);
        }
    }
    pageHTML() {
        return Promise.resolve(this._document.documentElement.outerHTML);
    }
}
exports.JSDOMAsyncHTMLDocument = JSDOMAsyncHTMLDocument;
class JSDOMAsyncHTMLElement {
    constructor(htmlelement) {
        this._htmlelement = htmlelement;
        this._ownerDocument = new JSDOMAsyncHTMLDocument(htmlelement.ownerDocument);
    }
    getAttribute(name) {
        return this._htmlelement.getAttribute(name);
    }
    isSame(element) {
        return this._htmlelement === element._htmlelement;
    }
    outerHTML() {
        return Promise.resolve(this._htmlelement.outerHTML);
    }
    get attributes() {
        return this._htmlelement.attributes;
    }
    get nodeName() {
        return this._htmlelement.nodeName;
    }
    get ownerDocument() {
        return this._ownerDocument;
    }
}
exports.JSDOMAsyncHTMLElement = JSDOMAsyncHTMLElement;
