"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const appInsights = require("applicationinsights");
const configStore = require("./configstore");
const debug_1 = require("./debug");
const debug = debug_1.debug(__filename);
const configStoreKey = 'insight';
let insightsEnabled = configStore.get(configStoreKey);
let appInsightsClient = {
    flush(options) {
        debug('Application Insights is not enabled.');
        options.callback();
    },
    trackEvent() {
        debug('Application Insights is not enabled.');
    },
    trackException() {
        debug('Application Insights is not enabled.');
    }
};
exports.enableInsight = () => {
    debug('Enabling Application Insights');
    appInsights.setup('8ef2b55b-2ce9-4c33-a09a-2c3ef605c97d')
        .setAutoDependencyCorrelation(true)
        .setAutoCollectRequests(true)
        .setAutoCollectPerformance(true)
        .setAutoCollectExceptions(true)
        .setAutoCollectDependencies(true)
        .setUseDiskRetryCaching(true)
        .setInternalLogging(false, false)
        .start();
    appInsightsClient = appInsights.defaultClient;
};
if (insightsEnabled) {
    exports.enableInsight();
}
else {
    debug('Application Insight disabled');
}
exports.isEnabled = () => {
    return insightsEnabled;
};
exports.enable = () => {
    debug('User is enabling Application Insights');
    configStore.set(configStoreKey, true);
    insightsEnabled = true;
    exports.enableInsight();
};
exports.disable = () => {
    debug('User is disabling Application Insights');
    configStore.set(configStoreKey, false);
    insightsEnabled = false;
};
exports.sendPendingData = (isAppCrashing = true) => {
    debug('Sending pending data to Application Insights');
    return new Promise((resolve) => {
        appInsightsClient.flush({
            callback: () => {
                resolve();
            },
            isAppCrashing
        });
    });
};
exports.trackException = (error) => {
    debug(`Sending exception to Application Insights: ${error.toString()}`);
    appInsightsClient.trackException({ exception: error });
};
exports.trackEvent = (name, properties) => {
    debug(`Sending event "${name}" to Application Insights with value ${JSON.stringify(properties)}`);
    appInsightsClient.trackEvent({ name, properties });
};
exports.getClient = () => {
    debug('Getting Application Insights client');
    return appInsightsClient;
};
exports.isConfigured = () => {
    return typeof configStore.get(configStoreKey) !== 'undefined';
};
