"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const url = require("url");
const url_1 = require("url");
const lodash_1 = require("lodash");
const fileUrl = require("file-url");
const debug_1 = require("../debug");
const logger = require("../logging");
const is_file_1 = require("../fs/is-file");
const is_directory_1 = require("../fs/is-directory");
const path_exists_1 = require("../fs/path-exists");
const debug = debug_1.debug(__filename);
exports.getAsUri = (source) => {
    const entry = source.trim();
    let target;
    try {
        target = new url_1.URL(entry);
    }
    catch (err) {
        {
            target = null;
        }
    }
    const protocol = target ? target.protocol : null;
    if (protocol === 'http:' || protocol === 'https:' || protocol === 'file:') {
        debug(`Adding valid target: ${url.format(target)}`);
        return target;
    }
    if (is_file_1.default(entry) || is_directory_1.default(entry)) {
        target = new url_1.URL(fileUrl(entry));
        debug(`Adding valid target: ${url.format(target)}`);
        return target;
    }
    target = new url_1.URL(`http://${entry}`);
    if (!path_exists_1.default(entry) && (target.hostname === 'localhost' || target.hostname.includes('.'))) {
        debug(`Adding modified target: ${url.format(target)}`);
        return target;
    }
    logger.error(`Ignoring '${entry}' as it's not an existing file nor a valid URL`);
    return null;
};
exports.getAsUris = (source) => {
    const targets = source.reduce((uris, entry) => {
        const uri = exports.getAsUri(entry);
        if (uri) {
            uris.push(uri);
        }
        return uris;
    }, []);
    return lodash_1.compact(targets);
};
